@@ -5,8 +5,15 @@ def test_math():
     g = mcf_graph()
     g = mcf_graph(5)
     g.add_edge(0, 1, 1, 1)
-    assert str(g.get_edge(0)) == "<edge from=0 to=1 cap=1 flow=0 cost=1>"
-    assert str(g.edges()) == "[<edge from=0 to=1 cap=1 flow=0 cost=1>]"
+
+    e = g.get_edge(0)
+    assert e.from_ == 0
+    assert e.to == 1
+    assert e.cap == 1
+    assert e.flow == 0
+    assert e.cost == 1
+    assert str(e) == "<edge from_=0 to=1 cap=1 flow=0 cost=1>"
+    assert str(g.edges()) == "[<edge from_=0 to=1 cap=1 flow=0 cost=1>]"
     e = mcf_graph.edge(0, 1, 1, 0, 1)
 
     assert g.flow(0, 1) == (1, 1)
